Struct google_cloudresourcemanager1::Constraint
source · pub struct Constraint {
pub constraint_default: Option<String>,
pub version: Option<i32>,
pub display_name: Option<String>,
pub description: Option<String>,
pub boolean_constraint: Option<BooleanConstraint>,
pub list_constraint: Option<ListConstraint>,
pub name: Option<String>,
}Expand description
A Constraint describes a way in which a resource’s configuration can be
restricted. For example, it controls which cloud services can be activated
across an organization, or whether a Compute Engine instance can have
serial port connections established. Constraints can be configured by the
organization’s policy adminstrator to fit the needs of the organzation by
setting Policies for Constraints at different locations in the
organization’s resource hierarchy. Policies are inherited down the resource
hierarchy from higher levels, but can also be overridden. For details about
the inheritance rules please read about
Policies.
Constraints have a default behavior determined by the constraint_default
field, which is the enforcement behavior that is used in the absence of a
Policy being defined or inherited for the resource in question.
This type is not used in any activity, and only used as part of another schema.
Fields
constraint_default: Option<String>The evaluation behavior of this constraint in the absense of ‘Policy’.
version: Option<i32>Version of the Constraint. Default version is 0;
display_name: Option<String>The human readable name.
Mutable.
description: Option<String>Detailed description of what this Constraint controls as well as how and
where it is enforced.
Mutable.
boolean_constraint: Option<BooleanConstraint>Defines this constraint as being a BooleanConstraint.
list_constraint: Option<ListConstraint>Defines this constraint as being a ListConstraint.
name: Option<String>Immutable value, required to globally be unique. For example,
constraints/serviceuser.services