Struct google_cloudresourcemanager1::GetEffectiveOrgPolicyRequest [−][src]
The request sent to the GetEffectiveOrgPolicy method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get effective org policy folders (request)
- get effective org policy organizations (request)
- get effective org policy projects (request)
Fields
constraint: Option<String>
The name of the Constraint to compute the effective Policy.