pub struct ListConstraint {
pub supports_under: Option<bool>,
pub suggested_value: Option<String>,
}Expand description
A Constraint that allows or disallows a list of string values, which are
configured by an Organization’s policy administrator with a Policy.
This type is not used in any activity, and only used as part of another schema.
Fields
supports_under: Option<bool>Indicates whether subtrees of Cloud Resource Manager resource hierarchy
can be used in Policy.allowed_values and Policy.denied_values. For
example, "under:folders/123" would match any resource under the
‘folders/123’ folder.
suggested_value: Option<String>Optional. The Google Cloud Console will try to default to a configuration
that matches the value specified in this Constraint.