Struct google_cloudresourcemanager1::ListOrgPoliciesRequest [−][src]
The request sent to the ListOrgPolicies method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list org policies organizations (request)
- list org policies projects (request)
- list org policies folders (request)
Fields
page_token: Option<String>
Page token used to retrieve the next page. This is currently unsupported and will be ignored. The server may at any point start using this field.
page_size: Option<i32>
Size of the pages to be returned. This is currently unsupported and will be ignored. The server may at any point start using this field to limit page size.