pub struct ProjectDeleteCall<'a, C, A>
where C: 'a, A: 'a,
{ /* private fields */ }
Marks the Project identified by the specified project_id (for example, my-project-123) for deletion. This method will only affect the Project if the following criteria are met:

  • The Project does not have a billing account associated with it.
  • The Project has a lifecycle state of ACTIVE.

This method changes the Project’s lifecycle state from ACTIVE to DELETE_REQUESTED. The deletion starts at an unspecified time, at which point the Project is no longer accessible.

Until the deletion completes, you can check the lifecycle state checked by retrieving the Project with GetProject, and the Project remains visible to ListProjects. However, you cannot update the project.

After the deletion completes, the Project is not retrievable by the GetProject and ListProjects methods.

The caller must have modify permissions for this Project.

A builder for the delete method supported by a project resource. It is not used directly, but through a ProjectMethods instance.

Example

Instantiate a resource method builder

 
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.projects().delete("projectId")
             .doit();

Implementations

source

impl<'a, C, A> ProjectDeleteCall<'a, C, A>
where C: BorrowMut<Client>, A: GetToken,

source

pub fn doit(self) -> Result<(Response, Empty)>

Perform the operation you have build so far.

source

pub fn project_id(self, new_value: &str) -> ProjectDeleteCall<'a, C, A>

The Project ID (for example, foo-bar-123).

Required.

Sets the project id path property to the given value.

Even though the property as already been set when instantiating this call, we provide this method for API completeness.

source

pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> ProjectDeleteCall<'a, C, A>

The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.

It should be used to handle progress information, and to implement a certain level of resilience.

Sets the delegate property to the given value.

source

pub fn param<T>(self, name: T, value: T) -> ProjectDeleteCall<'a, C, A>
where T: AsRef<str>,

Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.

Please note that this method must not be used to set any of the known paramters which have their own setter method. If done anyway, the request will fail.

Additional Parameters
  • bearer_token (query-string) - OAuth bearer token.
  • pp (query-boolean) - Pretty-print response.
  • prettyPrint (query-boolean) - Returns response with indentations and line breaks.
  • upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
  • access_token (query-string) - OAuth access token.
  • uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
  • quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
  • callback (query-string) - JSONP
  • oauth_token (query-string) - OAuth 2.0 token for the current user.
  • key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
  • fields (query-string) - Selector specifying which fields to include in a partial response.
  • alt (query-string) - Data format for response.
  • $.xgafv (query-string) - V1 error format.
source

pub fn add_scope<T>(self, scope: T) -> ProjectDeleteCall<'a, C, A>
where T: AsRef<str>,

Identifies the authorization scope for the method you are building.

Use this method to actively specify which scope should be used, instead the default Scope variant Scope::CloudPlatform.

The scope will be added to a set of scopes. This is important as one can maintain access tokens for more than one scope.

Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.